# DUNE example

DU&nu;E is a long-baseline neutrino oscillation experiment. It will use a
neutrino beam produced at Fermilab, and send it to a detector located 1300 km
away in South Dakota. The beam will contain both muon neutrinos and muon
antineutrinos, and the detector will be able to distinguish between the two. The
goal of the experiment is to measure the oscillation parameters of the
neutrinos, and to search for CP violation in the lepton sector.

```{note}
Interested in contributing? Head to the [GitHub repository](https://github.com/FAST-HEP/fasthep-flow) and open a pull request!
```
